import { Http, IEventParam, Metadata } from '@zeedhi/core';
import {
  AlertService, Form, Modal, ModalService, LoadingService,
} from '@zeedhi/common';
import {
  ZdGrid, ZdTabs,
} from '@zeedhi/vuetify';

export class Opl01600ParametrizacaoDoOPLController {
  private FiltroModal!: Modal;

  private Tab1AddModal!: Modal;

  private Tab1DeleteModal!: Modal;

  private Tab2AcrescentarModal!: Modal;

  private Tab2SubstituirModal!: Modal;

  private Tab2AddModal!: Modal;

  private Tab2DeleteModal!: Modal;

  private Tab3AddModal!: Modal;

  private Tab3DeleteModal!: Modal;

  public readOnlySubGrupProd: boolean = true;

  public filterValueCDFILIOPELOG: any = null;

  public filterValueCDFILIAL: Array<any> = [];

  public filterValueCDPRODINI: any = null;

  public filterValueCDPRODFIN: any = null;

  public filterValueCDMARCA: Array<any> = [];

  public filterValueCDSUBGRPPROD: Array<any> = [];

  public filterValueIDITEMSEMPARAM: any = 'T';

  public filterGrid2: any = {};

  public filterGrid3: any = {};

  public paraSupri: any = {};

  public async createFiltroModal() {
    LoadingService.show('Carregando...');
    
    this.FiltroModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_filtro', true);

    this.Tab1AddModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab1_modal1', true);

    this.Tab1DeleteModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab1_modal2', true);

    this.Tab2AcrescentarModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab2_modal1', true);

    this.Tab2SubstituirModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab2_modal2', true);

    this.Tab2AddModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab2_modal3', true);

    this.Tab2DeleteModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab2_modal4', true);

    this.Tab3AddModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab3_modal1', true);

    this.Tab3DeleteModal = await ModalService.createFromJson('pages/opl01600/opl01600_parametrizacao_do_opl_tab3_modal2', true);

    Http.get('crudN/parasupri?in=CDFILIAL&CDFILIAL=FILIAL_LOGADA').then((response) => {
      this.paraSupri = response.data.data[0];
      
      this.FiltroModal.show();
      
      LoadingService.hide();
    });
  }

  public destroyFiltroModal() {
    this.FiltroModal?.destroy();
  }

  public async abrirFiltroModal() {
    this.FiltroModal.show();
  }

  public fecharFiltroModal() {
    this.FiltroModal.hide();
  }

  public validaFiltro() {
    const form = Metadata.getInstance<Form>('formFiltro');
    const valid = form.validate();

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'filtroInvalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      this.loadGrid1();

      this.fecharFiltroModal();
    }
  }

  public onChangeSwitchSubGrupProd({ component }: IEventParam<any>) {
    if (this.readOnlySubGrupProd) {
      this.filterValueCDSUBGRPPROD = [];
      component.parent.children.forEach((child: { name: any; value: any; }) => {
        if (child.name === 'CDSUBGRPROD') {
          child.value = [];
        }
      });
    }
  }

  public openFieldCDFILIAL({ component }: IEventParam<any>) {
    component.datasource.data = [];

    component.datasource.filter.P_CDFILIAL = this.filterValueCDFILIOPELOG != null ? this.filterValueCDFILIOPELOG.CDFILIAL : 'T';

    component.datasource.get().then((response: any) => {
      component.updateData(response);
    });
  }

  public onChangeFieldsFiltro({ component }: IEventParam<any>) {
    const form = Metadata.getInstance<Form>('formFiltro');

    switch (component.name) {
      case 'CDFILIOPELOG': {
        this.filterValueCDFILIOPELOG = component.value;

        const fieldCDFILIAL = form.getChildInstance<any>('CDFILIAL');

        fieldCDFILIAL.unSelectAllItems();

        break;
      }
      case 'CDFILIAL': {
        this.filterValueCDFILIAL = component.value;
        break;
      }
      case 'CDPRODINI': {
        this.filterValueCDPRODINI = component.value;
        break;
      }
      case 'CDPRODFIN': {
        this.filterValueCDPRODFIN = component.value;
        break;
      }
      case 'CDMARCA': {
        this.filterValueCDMARCA = component.value;
        break;
      }
      case 'CDSUBGRPROD': {
        this.filterValueCDSUBGRPPROD = component.value;
        break;
      }
      case 'IDITEMSEMPARAM': {
        this.filterValueIDITEMSEMPARAM = component.value;
        break;
      }
      default: break;
    }
  }

  public onFilterOpen({ component }: IEventParam<any>) {
    const fieldCDFILIOPELOG = component.getChildInstance('CDFILIOPELOG');
    const fieldCDPRODINI = component.getChildInstance('CDPRODINI');
    const fieldCDPRODFIN = component.getChildInstance('CDPRODFIN');
    const fieldCDFILIAL = component.getChildInstance('CDFILIAL');
    const fieldCDMARCA = component.getChildInstance('CDMARCA');
    const fieldCDSUBGRPROD = component.getChildInstance('CDSUBGRPROD');
    const fieldIDITEMSEMPARAM = component.getChildInstance('IDITEMSEMPARAM');
    
    fieldCDSUBGRPROD.datasource.filter = {
      P_CDGRUPPROD: this.paraSupri.CDGRUPPROD,
      P_CDSUBGRPROD: this.paraSupri.CDSUBGRARVOR,
    };

    fieldCDFILIOPELOG.setValue(this.filterValueCDFILIOPELOG != null ? this.filterValueCDFILIOPELOG.CDFILIAL : null);
    fieldCDPRODINI.setValue(this.filterValueCDPRODINI != null ? this.filterValueCDPRODINI.CDARVPROD : null);
    fieldCDPRODFIN.setValue(this.filterValueCDPRODFIN != null ? this.filterValueCDPRODFIN.CDARVPROD : null);
    fieldIDITEMSEMPARAM.setValue(this.filterValueIDITEMSEMPARAM != null ? this.filterValueIDITEMSEMPARAM : 'T');

    const cdfiliais: any[] = [];
    const cdmarcas: any[] = [];
    const cdsubgrpprods: any[] = [];

    this.filterValueCDFILIAL.forEach((val) => {
      if (fieldCDFILIAL.value.indexOf(val.CDFILIAL) === -1) {
        cdfiliais.push(val.CDFILIAL);
      }
    });

    fieldCDFILIAL.setValue(cdfiliais.length > 0 ? cdfiliais : []);

    this.filterValueCDMARCA.forEach((val) => {
      if (fieldCDMARCA.value.indexOf(val.CDMARCA) === -1) {
        cdmarcas.push(val.CDMARCA);
      }
    });

    fieldCDMARCA.setValue(cdmarcas.length > 0 ? cdmarcas : []);

    this.filterValueCDSUBGRPPROD.forEach((val) => {
      if (fieldCDSUBGRPROD.value.indexOf(val.CDSUBGRPROD) === -1) {
        cdsubgrpprods.push(val.CDSUBGRPROD);
      }
    });

    fieldCDSUBGRPROD.setValue(cdsubgrpprods.length > 0 ? cdsubgrpprods : []);
  }

  public reload({ component }: any) {
    if (component.name === 'tipoOperacaoOLGrid' || component.parent.name === 'tipoOperacaoOLGrid') {
      component.parent.datasource.get();
    }

    if (component.name === 'parametrizacaoDeProdutoPorUnidadeGrid' || component.parent.name === 'parametrizacaoDeProdutoPorUnidadeGrid') {
      component.parent.datasource.filter = this.filterGrid2;
      component.parent.datasource.get();
    }

    if (component.name === 'parametrizacaoGeralDeProdutosGrid' || component.parent.name === 'parametrizacaoGeralDeProdutosGrid') {
      component.parent.datasource.filter = this.filterGrid3;
      component.parent.datasource.get();
    }
  }

  public loadGrid1() {
    const grid = Metadata.getInstance<ZdGrid>('tipoOperacaoOLGrid');
    const tabs = Metadata.getInstance<ZdTabs>('tabsParametrizacaoOPL');
    const arrayCDFILIAL: Array<any> = [];
    const arrayCDSUBGRPPROD: Array<any> = [];
    const arrayCDMARCA: Array<any> = [];
    let valueCDFILIAL: String = '';
    let valueCDSUBGRPPROD: String = '';
    let valueCDMARCA: String = '';
    
    tabs.activeTab = 0;
    
    if (this.filterValueCDFILIAL.length > 0) {
      this.filterValueCDFILIAL.forEach((val) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    }
    
    if (this.filterValueCDSUBGRPPROD.length > 0) {
      this.filterValueCDSUBGRPPROD.forEach((val) => {
        arrayCDSUBGRPPROD.push(val.CDSUBGRPROD);
      });
      valueCDSUBGRPPROD = String('_').concat(arrayCDSUBGRPPROD.join('_').concat(String('_')));
    }
    
    if (this.filterValueCDMARCA.length > 0) {
      this.filterValueCDMARCA.forEach((val) => {
        arrayCDMARCA.push(val.CDMARCA);
      });
      valueCDMARCA = String('_').concat(arrayCDMARCA.join('_').concat(String('_')));
    }
    
    setTimeout(() => {
      const newFilter1 = {
        P_CDFILIAL: this.filterValueCDFILIAL.length > 0 ? valueCDFILIAL : 'T',
        P_OPERLOG: this.filterValueCDFILIOPELOG.CDFILIAL,
        P_CDOPERADOR: 'OPERADOR_LOGADO',
        P_IDITEMSEMPARAM: this.filterValueIDITEMSEMPARAM,
      };
      const newFilter2 = {
        P_NMPRODINI: this.filterValueCDPRODINI.NMPRODUTO,
        P_NMPRODFIN: this.filterValueCDPRODFIN.NMPRODUTO,
        P_CDFILIAL: this.filterValueCDFILIAL.length > 0 ? valueCDFILIAL : '',
        P_SUBGRUPO: this.filterValueCDSUBGRPPROD.length > 0 ? valueCDSUBGRPPROD : 'N',
        P_CDPRODINI: this.filterValueCDPRODINI.CDARVPROD,
        P_CDFILIOL: String('_').concat(String(this.filterValueCDFILIOPELOG.CDFILIAL).concat(String('_'))),
        P_TCDFILIOL: '',
        P_TCDFILIAL: this.filterValueCDFILIAL.length > 0 ? '' : 'T',
        P_CDPRODFIN: (String(this.filterValueCDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
        P_CDPRODFINTEXT: this.filterValueCDPRODFIN.CDARVPROD,
        P_IDUTLSUBGRPRODFIL: this.paraSupri.IDUTLSUBGRPRODFIL,
        P_CDFILIOPELOG: this.filterValueCDFILIOPELOG.CDFILIAL,
        P_IDITEMSEMPARAM: this.filterValueIDITEMSEMPARAM,
        P_CDGRUPPROD: this.paraSupri.CDGRUPPROD,
        P_CDSUBGRARVOR: this.paraSupri.CDSUBGRARVOR,
      };
      const newFilter3 = {
        P_CDFILIAL: 'FILIAL_LOGADA',
        P_SUBGRUPO: this.filterValueCDSUBGRPPROD.length > 0 ? valueCDSUBGRPPROD : 'N',
        P_CDMARCA: this.filterValueCDMARCA.length > 0 ? valueCDMARCA : 'T',
        P_CDPRODINI: this.filterValueCDPRODINI.CDARVPROD,
        P_CDPRODFIN: (String(this.filterValueCDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
        P_IDUTLSUBGRPRODFIL: this.paraSupri.IDUTLSUBGRPRODFIL,
        P_CDFILIOPELOG: this.filterValueCDFILIOPELOG.CDFILIAL,
        P_IDITEMSEMPARAM: this.filterValueIDITEMSEMPARAM,
      };
      
      this.filterGrid2 = newFilter2;
      this.filterGrid3 = newFilter3;
  
      grid.datasource.filter = newFilter1;
      grid.datasource.get();
    }, 50);
  }

  public loadGrid2({ component }: any) {
    component.datasource.filter = this.filterGrid2;
    component.datasource.get();
  }

  public loadGrid3({ component }: any) {
    component.datasource.filter = this.filterGrid3;
    component.datasource.get();
  }

  public abrirTab1AddModal() {
    this.Tab1AddModal.show();
    
    setTimeout(() => {
      const form = Metadata.getInstance<any>('formTab1ModalAdd');
      
      const field = form.getChildInstance('CDFILIOPELOG');
      
      field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
    }, 100);
  }

  public fecharTab1ModalAdd() {
    this.Tab1AddModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('tipoOperacaoOLGrid');
      
      grid.reload();
    }, 100);
  }

  public abrirTab1DeleteModal() {
    this.Tab1DeleteModal.show();
    
    setTimeout(() => {
      const form = Metadata.getInstance<any>('formTab1ModalDelete');
      
      const field = form.getChildInstance('CDFILIOPELOG');
      
      field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
    }, 100);
  }

  public fecharTab1ModalDelete() {
    this.Tab1DeleteModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('tipoOperacaoOLGrid');
      
      grid.reload();
    }, 100);
  }

  public async onTab1ModalAddOpen({ component }: IEventParam<any>) {
    const field = component.getChildInstance('CDFILIOPELOG');
    const fieldSerie = component.getChildInstance('CDSERIE');
    
    fieldSerie.datasource.filter.P_CDFILIOPELOG = this.filterValueCDFILIOPELOG.CDFILIAL;

    await field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
  }

  public async onTab1ModalDeleteOpen({ component }: IEventParam<any>) {
    const field = component.getChildInstance('CDFILIOPELOG');

    await field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
  }

  public abrirTab2AcrescentarModal() {
    this.Tab2AcrescentarModal.show();
  }

  public fecharTab2ModalAcrescentar() {
    this.Tab2AcrescentarModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoDeProdutoPorUnidadeGrid');
      
      grid.reload();
    }, 100);
  }

  public abrirTab2SubstituirModal() {
    this.Tab2SubstituirModal.show();
  }

  public fecharTab2ModalSubstituir() {
    this.Tab2SubstituirModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoDeProdutoPorUnidadeGrid');
      
      grid.reload();
    }, 100);
  }

  public abrirTab2AddModal() {
    this.Tab2AddModal.show();
    
    setTimeout(() => {
      const form = Metadata.getInstance<any>('formTab2ModalAdd');
      
      const field = form.getChildInstance('CDFILIOPELOG');
      
      field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
    }, 100);
  }

  public fecharTab2ModalAdd() {
    this.Tab2AddModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoDeProdutoPorUnidadeGrid');
      
      grid.reload();
    }, 100);
  }

  public abrirTab2DeleteModal() {
    this.Tab2DeleteModal.show();
    
    setTimeout(() => {
      const form = Metadata.getInstance<any>('formTab2ModalDelete');
      
      const field = form.getChildInstance('CDFILIOPELOG');
      
      field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
    }, 100);
  }

  public fecharTab2ModalDelete() {
    this.Tab2DeleteModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoDeProdutoPorUnidadeGrid');
      
      grid.reload();
    }, 100);
  }

  public async onTab2ModalAddOpen({ component }: IEventParam<any>) {
    const field = component.getChildInstance('CDFILIOPELOG');
    const fieldCDSUBGRPROD = component.getChildInstance('CDSUBGRPROD');
    
    fieldCDSUBGRPROD.datasource.filter = {
      P_CDGRUPPROD: this.paraSupri.CDGRUPPROD,
      P_CDSUBGRPROD: this.paraSupri.CDSUBGRARVOR,
    };

    await field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
  }

  public async onTab2ModalDeleteOpen({ component }: IEventParam<any>) {
    const field = component.getChildInstance('CDFILIOPELOG');
    const fieldCDSUBGRPROD = component.getChildInstance('CDSUBGRPROD');
    
    fieldCDSUBGRPROD.datasource.filter = {
      P_CDGRUPPROD: this.paraSupri.CDGRUPPROD,
      P_CDSUBGRPROD: this.paraSupri.CDSUBGRARVOR,
    };

    await field.setValue(this.filterValueCDFILIOPELOG.CDFILIAL);
  }

  public tab2OnChangeRegiao({ component }: IEventParam<any>) {
    const form = component.parent;
    const fieldRegiao = component;
    const fieldUnidade = form.getChildInstance('CDFILIAL');

    fieldUnidade.setValue([]);
    
    setTimeout(() => {
      if (fieldRegiao.value.length > 0) {
        const cdregioes: any[] = [];
  
        fieldRegiao.value.forEach((reg: any) => {
          cdregioes.push(reg.CDREGIAO);
        });
  
        fieldUnidade.datasource.filter.P_CDREGIAO = String('_').concat(String(cdregioes.join('_')).concat(String('_')));
      } else {
        fieldUnidade.datasource.filter.P_CDREGIAO = 'T';
      }
  
      fieldUnidade.datasource.get();
    }, 500);
  }

  public abrirTab3AddModal() {
    this.Tab3AddModal.show();
  }

  public fecharTab3ModalAdd() {
    this.Tab3AddModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoGeralDeProdutosGrid');
      
      grid.reload();
    }, 100);
  }

  public abrirTab3DeleteModal() {
    this.Tab3DeleteModal.show();
  }

  public fecharTab3ModalDelete() {
    this.Tab3DeleteModal.hide();
    
    setTimeout(() => {
      const grid = Metadata.getInstance<any>('parametrizacaoGeralDeProdutosGrid');
      
      grid.reload();
    }, 100);
  }

  public async concluirTab1ModalAdd() {
    const form = Metadata.getInstance<Form>('formTab1ModalAdd');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    let valueCDFILIAL: String = '';

    if (form.value.CDFILIAL.length > 0) {
      form.value.CDFILIAL.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILIOPELOG: form.value.CDFILIOPELOG.CDFILIAL,
        CDFILDEST: valueCDFILIAL,
        CDTIPOOPERSAID: form.value.CDTIPOOPERSAID.CDTIPOOPER,
        CDTIPOOPERENTR: form.value.CDTIPOOPERENTR.CDTIPOOPER,
        CDCLIENTE: form.value.CDCLIENTE !== null ? form.value.CDCLIENTE.CDLIENTE : null,
        CDSERIE: form.value.CDSERIE !== null ? form.value.CDSERIE.CDSERIE : null,
      };

      await Http.post('inclusaoAutTipoOperOPL', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab1ModalAdd();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab1ModalDelete() {
    const form = Metadata.getInstance<Form>('formTab1ModalDelete');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    let valueCDFILIAL: String = '';

    if (form.value.CDFILIAL.length > 0) {
      form.value.CDFILIAL.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILIOPELOG: form.value.CDFILIOPELOG.CDFILIAL,
        CDFILDEST: valueCDFILIAL,
      };

      await Http.post('exclusaoAutTipoOperOPL', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab1ModalDelete();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab2ModalAcrescentar() {
    const form = Metadata.getInstance<Form>('formTab2ModalAcrescentar');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    let valueCDFILIAL: String = '';

    if (form.value.CDFILDEST.length > 0) {
      form.value.CDFILDEST.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILORIG: form.value.CDFILORIG.CDFILIAL,
        CDFILDEST: valueCDFILIAL,
      };

      await Http.post('acrAutParamProdSupFili', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab2ModalAcrescentar();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab2ModalSubstituir() {
    const form = Metadata.getInstance<Form>('formTab2ModalSubstituir');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    let valueCDFILIAL: String = '';

    if (form.value.CDFILDEST.length > 0) {
      form.value.CDFILDEST.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILORIG: form.value.CDFILORIG.CDFILIAL,
        CDFILDEST: valueCDFILIAL,
      };

      await Http.post('subAutParamProdSupFili', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab2ModalSubstituir();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab2ModalAdd() {
    const form = Metadata.getInstance<Form>('formTab2ModalAdd');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    const arrayCDREGIAO: Array<any> = [];
    const arrayCDSUBGRPPROD: Array<any> = [];
    let valueCDFILIAL: String = '';
    let valueCDREGIAO: String = '';
    let valueCDSUBGRPPROD: String = '';

    if (form.value.CDFILIAL.length > 0) {
      form.value.CDFILIAL.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (form.value.CDREGIAO.length > 0) {
      form.value.CDREGIAO.forEach((val: any) => {
        arrayCDREGIAO.push(val.CDREGIAO);
      });
      valueCDREGIAO = String('_').concat(arrayCDREGIAO.join('_').concat(String('_')));
    } else {
      valueCDREGIAO = 'T';
    }

    if (form.value.CDSUBGRPROD.length > 0) {
      form.value.CDSUBGRPROD.forEach((val: any) => {
        arrayCDSUBGRPPROD.push(val.CDSUBGRPROD);
      });
      valueCDSUBGRPPROD = String('_').concat(arrayCDSUBGRPPROD.join('_').concat(String('_')));
    } else {
      valueCDSUBGRPPROD = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILIOPELOG: form.value.CDFILIOPELOG.CDFILIAL,
        CDREGIAO: valueCDREGIAO,
        CDFILIAL: valueCDFILIAL,
        CDGRUPPROD: this.paraSupri.CDGRUPPROD,
        CDSUBGRPROD: valueCDSUBGRPPROD,
        CDPRODINI: form.value.CDPRODINI.CDARVPROD,
        CDPRODFIN: (String(form.value.CDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
      };

      await Http.post('inclusaoCadAutParamProdSup', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab2ModalAdd();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab2ModalDelete() {
    const form = Metadata.getInstance<Form>('formTab2ModalDelete');
    const valid = form.validate();
    const arrayCDFILIAL: Array<any> = [];
    const arrayCDREGIAO: Array<any> = [];
    const arrayCDSUBGRPPROD: Array<any> = [];
    let valueCDFILIAL: String = '';
    let valueCDREGIAO: String = '';
    let valueCDSUBGRPPROD: String = '';

    if (form.value.CDFILIAL.length > 0) {
      form.value.CDFILIAL.forEach((val: any) => {
        arrayCDFILIAL.push(val.CDFILIAL);
      });
      valueCDFILIAL = String('_').concat(arrayCDFILIAL.join('_').concat(String('_')));
    } else {
      valueCDFILIAL = 'T';
    }

    if (form.value.CDREGIAO.length > 0) {
      form.value.CDREGIAO.forEach((val: any) => {
        arrayCDREGIAO.push(val.CDREGIAO);
      });
      valueCDREGIAO = String('_').concat(arrayCDREGIAO.join('_').concat(String('_')));
    } else {
      valueCDREGIAO = 'T';
    }

    if (form.value.CDSUBGRPROD.length > 0) {
      form.value.CDSUBGRPROD.forEach((val: any) => {
        arrayCDSUBGRPPROD.push(val.CDSUBGRPROD);
      });
      valueCDSUBGRPPROD = String('_').concat(arrayCDSUBGRPPROD.join('_').concat(String('_')));
    } else {
      valueCDSUBGRPPROD = 'T';
    }

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDFILIOPELOG: form.value.CDFILIOPELOG.CDFILIAL,
        CDREGIAO: valueCDREGIAO,
        CDFILIAL: valueCDFILIAL,
        CDGRUPPROD: this.paraSupri.CDGRUPPROD,
        CDSUBGRPROD: valueCDSUBGRPPROD,
        CDPRODINI: form.value.CDPRODINI.CDARVPROD,
        CDPRODFIN: (String(form.value.CDPRODFIN.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
      };

      await Http.post('exclusaoCadAutParamProdSup', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab2ModalDelete();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab3ModalAdd() {
    const form = Metadata.getInstance<Form>('formTab3ModalAdd');
    const valid = form.validate();

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDPRODINIOL: form.value.CDPRODINIOL.CDARVPRODOL,
        CDPRODFINOL: (String(form.value.CDPRODFINOL.CDARVPRODOL).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
        CDPRODINI: form.value.CDPRODINIORIG.CDARVPROD,
        CDPRODFIN: (String(form.value.CDPRODFINORIG.CDARVPROD).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
        CDMARCA: form.value.CDMARCA.CDMARCA,
        CDFILIOPELOG: this.filterValueCDFILIOPELOG.CDFILIAL,
      };

      await Http.post('inclusaoCadAutRelacProdOL', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab3ModalAdd();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }

  public async concluirTab3ModalDelete() {
    const form = Metadata.getInstance<Form>('formTab3ModalDelete');
    const valid = form.validate();

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'invalidoAltert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      form.submit();

      const row = {
        CDPRODINIOL: form.value.CDPRODINIOL.CDARVPRODOL,
        CDPRODFINOL: (String(form.value.CDPRODFINOL.CDARVPRODOL).concat(String('ZZZZZZZZZZZZZZZZZZZZ'))).substring(0, 20),
      };

      await Http.post('exclusaoCadAutRelacProdOL', { requestType: 'Row', row }).then((response) => {
        if (response.data.error !== undefined) {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Por favor entre em contato com o Suporte Teknisa!',
            color: 'error',
          });
        } else if (response.data.dataset.data.P_ERROS === 'N') {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'successAlert',
            text: 'Processo concluído com sucesso!',
            color: 'success',
          });
          
          form.clearForm();

          this.fecharTab3ModalDelete();
        } else {
          AlertService.show({
            top: true,
            right: true,
            timeout: 2000,
            name: 'errorAlert',
            text: 'Não foi possível concluir o processo!<br>Não há dados!',
            color: 'error',
          });
        }
      });
    }
  }
  
  public onChangeTab({ component }: any) {
    setTimeout(() => {
      if (component.activeTabValue === 1) {
        const grid2 = Metadata.getInstance<ZdGrid>('parametrizacaoDeProdutoPorUnidadeGrid');
    
        grid2.datasource.filter = this.filterGrid2;
        grid2.datasource.get();
      }
      if (component.activeTabValue === 2) {
        const grid3 = Metadata.getInstance<ZdGrid>('parametrizacaoGeralDeProdutosGrid');
    
        grid3.datasource.filter = this.filterGrid3;
        grid3.datasource.get();
      }
    }, 10);
  }
  
  public changeMarca({ component }: any) {
    const form = Metadata.getInstance<Form>('formTab3ModalAdd');
    const prodOriIni = form.getChildInstance<any>('CDPRODINIORIG');
    const prodOriFin = form.getChildInstance<any>('CDPRODFINORIG');
    
    if (component.value === null) {
      prodOriIni.readonly = true;
      prodOriFin.readonly = true;
  
      prodOriIni.setValue(null);
      prodOriFin.setValue(null);
    } else {
      prodOriIni.readonly = false;
      prodOriFin.readonly = false;
      
      const filter = {
        P_CDFILIAL: 'FILIAL_LOGADA',
        P_CDMARCA: component.value.CDMARCA,
      };
      
      prodOriIni.datasource.filter = filter;
      prodOriFin.datasource.filter = filter;
      
      prodOriIni.datasource.get();
      prodOriFin.datasource.get();
    }
  }
}
